pub struct RegisterStakerPayload {
pub authority: Pubkey,
pub mint: Pubkey,
}Fields
The authority of the member account sending the payload.
mint: PubkeyThe mint for the boost account the member is staking to.